function importFACS = importfile(filename, dataLines)
%IMPORTFILE1 Import data from a text file
%  C1UPDATED = IMPORTFILE1(FILENAME) reads data from text file FILENAME
%  for the default selection.  Returns the data as a table.
%
%  C1UPDATED = IMPORTFILE1(FILE, DATALINES) reads data for the specified
%  row interval(s) of text file FILENAME. Specify DATALINES as a
%  positive scalar integer or a N-by-2 array of positive scalar integers
%  for dis-contiguous row intervals.
%
%  Example:
%  C1Updated = importfile1("/Users/AnaSierra/Downloads/MATLAB/C1_Updated.txt", [3, Inf]);
%
%  See also READTABLE.
%
% Auto-generated by MATLAB on 26-May-2020 16:26:01

%% Input handling

% If dataLines is not specified, define defaults
if nargin < 2
    dataLines = [3, Inf];
end

%% Setup the Import Options
opts = delimitedTextImportOptions("NumVariables", 14);

% Specify range and delimiter
opts.DataLines = dataLines;
opts.Delimiter = "\t";

% Specify column names and types
opts.VariableNames = ["Event", "FSCA", "FSCH", "FSCW", "SSCA", "SSCH", "SSCW", "PETexasRedA", "PETexasRedH", "PETexasRedW", "Time"];
opts.VariableTypes = ["double", "double", "double", "double", "double", "double", "double", "double", "double", "double", "double"];
opts.ExtraColumnsRule = "ignore";
opts.EmptyLineRule = "read";

% Import the data
importFACS = readtable(filename, opts);

end